@@ -29,17 +29,18 @@
  */
 class Translate
 {
-	var $dir;						// Directories that contains /langs subdirectory
+	var $dir;							// Directories that contains /langs subdirectory
 
-	var $defaultlang;				// Current language for current user
-	var $direction = 'ltr';			// Left to right or Right to left
+	var $defaultlang;					// Current language for current user
+	var $direction = 'ltr';				// Left to right or Right to left
 	var $charset_inputfile=array();	// To store charset encoding used for language
-	var $charset_output='UTF-8';	// Codage used by "trans" method outputs
+	var $charset_output='UTF-8';		// Codage used by "trans" method outputs
 
 	var $tab_translate=array();		// Array of all translations key=>value
-	private $_tab_loaded=array();	// Array to store result after loading each language file
+	private $_tab_loaded=array();		// Array to store result after loading each language file
 
-	var $cache_labels=array();		// Cache for labels return by getLabelFromKey method
+	var $cache_labels=array();			// Cache for labels return by getLabelFromKey method
+	var $cache_currencies=array();		// Cache to store currency symbols
 
 
 
@@ -60,7 +61,7 @@ class Translate
 	/**
 	 *  Set accessor for this->defaultlang
 	 *
-	 *  @param	string	$srclang     	Language to use
+	 *  @param	string	$srclang     	Language to use. If '' or 'auto', we use browser lang.
 	 *  @return	void
 	 */
 	function setDefaultLang($srclang='en_US')
@@ -105,11 +106,12 @@ class Translate
 			// Array force long code from first part, even if long code is defined
 			$longforshort=array('ar'=>'ar_SA');
 			if (isset($longforshort[strtolower($langpart[0])])) $srclang=$longforshort[strtolower($langpart[0])];
-			else {
+			else if (! is_numeric($langpart[1])) {		// Second part YY may be a numeric with some Chrome browser
 				$srclang=strtolower($langpart[0])."_".strtoupper($langpart[1]);
 				$longforlong=array('no_nb'=>'nb_NO');
 				if (isset($longforlong[strtolower($srclang)])) $srclang=$longforlong[strtolower($srclang)];
 			}
+			else $srclang=strtolower($langpart[0])."_".strtoupper($langpart[0]);
 		}
 		else {						// If it's for a codetouse that is a short code xx
     	    // Array to convert short lang code into long code.
@@ -143,7 +145,7 @@ class Translate
 	 *  If data for file already loaded, do nothing.
 	 * 	All data in translation array are stored in UTF-8 format.
      *  tab_loaded is completed with $domain key.
-     *  Warning: MAIN_USE_CUSTOM_TRANSLATION is an old deprecated feature. Do not use it. It will revert 
+     *  Warning: MAIN_USE_CUSTOM_TRANSLATION is an old deprecated feature. Do not use it. It will revert
      *  rule "we keep first entry found with we keep last entry found" so it is probably not what you want to do.
      *
      *  Value for hash are: 1:Loaded from disk, 2:Not found, 3:Loaded from cache
@@ -193,7 +195,7 @@ class Translate
 
 		// Redefine alt
 		$langarray=explode('_',$langofdir);
-		if ($alt < 1 && strtolower($langarray[0]) == strtolower($langarray[1])) $alt=1;
+		if ($alt < 1 && isset($langarray[1]) && strtolower($langarray[0]) == strtolower($langarray[1])) $alt=1;
 		if ($alt < 2 && (strtolower($langofdir) == 'en_us' || strtolower($langofdir) == 'fr_fr' || strtolower($langofdir) == 'es_es')) $alt=2;
 
 		foreach($this->dir as $keydir => $searchdir)
@@ -204,7 +206,7 @@ class Translate
 
 			$filelangexists=is_file($file_lang_osencoded);
 
-			//dol_syslog('Translate::Load Try to read for alt='.$alt.' langofdir='.$langofdir.' file_lang='.$file_lang." => filelangexists=".$filelangexists);
+			//dol_syslog(get_class($this).'::Load Try to read for alt='.$alt.' langofdir='.$langofdir.' newdomain='.$domain.' modulename='.$modulename.' file_lang='.$file_lang." => filelangexists=".$filelangexists);
 
 			if ($filelangexists)
 			{
@@ -642,13 +644,15 @@ class Translate
 	 *      Store key-label found into cache variable $this->cache_labels to save SQL requests to get labels.
 	 *
 	 * 		@param	DoliBD	$db				Database handler
-	 * 		@param	string	$key			Key to get label (key in language file)
+	 * 		@param	string	$key			Translation key to get label (key in language file)
 	 * 		@param	string	$tablename		Table name without prefix
 	 * 		@param	string	$fieldkey		Field for key
 	 * 		@param	string	$fieldlabel		Field for label
+	 *      @param	string	$keyforselect	Use another value than the translation key for the where into select
 	 *      @return string					Label in UTF8 (but without entities)
+	 *      @see dol_getIdFromCode
 	 */
-	function getLabelFromKey($db,$key,$tablename,$fieldkey,$fieldlabel)
+	function getLabelFromKey($db,$key,$tablename,$fieldkey,$fieldlabel,$keyforselect='')
 	{
 		// If key empty
 		if ($key == '') return '';
@@ -669,7 +673,7 @@ class Translate
 
 		$sql = "SELECT ".$fieldlabel." as label";
 		$sql.= " FROM ".MAIN_DB_PREFIX.$tablename;
-		$sql.= " WHERE ".$fieldkey." = '".$key."'";
+		$sql.= " WHERE ".$fieldkey." = '".($keyforselect?$keyforselect:$key)."'";
 		dol_syslog(get_class($this).'::getLabelFromKey sql='.$sql,LOG_DEBUG);
 		$resql = $db->query($sql);
 		if ($resql)
@@ -689,6 +693,108 @@ class Translate
 		}
 	}
 
+
+	/**
+	 *	Return a currency code into its symbol
+	 *
+	 *  @param	string	$currency_code		Currency Code
+	 *  @param	string	$amount				If not '', show currency + amount according to langs ($10, 10€).
+	 *  @return	string						Amount + Currency symbol encoded into UTF8
+	 */
+	function getCurrencyAmount($currency_code, $amount)
+	{
+		$symbol=$this->getCurrencSymbol($currency_code);
+
+		if (in_array($currency_code, array('USD'))) return $symbol.$amount;
+		else return $amount.$symbol;
+	}
+
+	/**
+	 *	Return a currency code into its symbol
+	 *
+	 *  @param	string	$currency_code		Currency code
+	 *  @param	string	$forceloadall		1=Force to load all currencies into cache. We know we need to use all of them. By default read and cache only required currency.
+	 *  @return	string						Currency symbol encoded into UTF8
+	 */
+	function getCurrencySymbol($currency_code, $forceloadall=0)
+	{
+		$currency_sign = '';	// By default return iso code
+
+		if (function_exists("mb_convert_encoding"))
+		{
+			$this->load_cache_currencies($forceloadall?'':$currency_code);
+
+			if (isset($this->cache_currencies[$currency_code]) && ! empty($this->cache_currencies[$currency_code]['unicode']) && is_array($this->cache_currencies[$currency_code]['unicode']))
+			{
+				foreach($this->cache_currencies[$currency_code]['unicode'] as $unicode)
+				{
+					$currency_sign .= mb_convert_encoding("&#{$unicode};", "UTF-8", 'HTML-ENTITIES');
+				}
+			}
+		}
+
+		return ($currency_sign?$currency_sign:$currency_code);
+	}
+
+	/**
+	 *  Load into the cache, all currencies
+	 *
+	 *	@param	string	$currency_code		Get only currency. Get all if ''.
+	 *  @return int             			Nb of loaded lines, 0 if already loaded, <0 if KO
+	 */
+	function load_cache_currencies($currency_code)
+	{
+		global $db;
+
+		if (! empty($currency_code) && isset($this->cache_currencies[$currency_code])) return 0;    // Value already into cache
+
+		$sql = "SELECT code_iso, label, unicode";
+		$sql.= " FROM ".MAIN_DB_PREFIX."c_currencies";
+		$sql.= " WHERE active = 1";
+		if (! empty($currency_code)) $sql.=" AND code_iso = '".$currency_code."'";
+		//$sql.= " ORDER BY code_iso ASC"; // Not required, a sort is done later
+
+		dol_syslog(get_class($this).'::load_cache_currencies sql='.$sql, LOG_DEBUG);
+		$resql = $db->query($sql);
+		if ($resql)
+		{
+			$this->load("dict");
+			$label=array();
+			foreach($this->cache_currencies as $key => $val) $label[$key]=$val['label'];
+
+			$num = $db->num_rows($resql);
+			$i = 0;
+			while ($i < $num)
+			{
+				$obj = $db->fetch_object($resql);
+
+				// Si traduction existe, on l'utilise, sinon on prend le libelle par defaut
+				$this->cache_currencies[$obj->code_iso]['label'] = ($obj->code_iso && $this->trans("Currency".$obj->code_iso)!="Currency".$obj->code_iso?$this->trans("Currency".$obj->code_iso):($obj->label!='-'?$obj->label:''));
+				$this->cache_currencies[$obj->code_iso]['unicode'] = (array) json_decode($obj->unicode, true);
+				$label[$obj->code_iso] = $this->cache_currencies[$obj->code_iso]['label'];
+				$i++;
+			}
+			//print count($label).' '.count($this->cache_currencies);
+			array_multisort($label, SORT_ASC, $this->cache_currencies);
+			//var_dump($this->cache_currencies);	$this->cache_currencies is now sorted onto label
+			return $num;
+		}
+		else
+		{
+			dol_print_error($db);
+			return -1;
+		}
+	}
+
+	function get_translations_for_substitutions() {
+		$substitutionarray = array();
+
+		foreach($this->tab_translate as $code => $label) {
+			$substitutionarray['lang_'.$code] = $label;
+		}
+
+		return $substitutionarray;
+	}
 }
 
 ?>
