@@ -27,12 +27,12 @@
  *	\brief      Fichier de la classe permettant de gerer une base pgsql
  */
 
+require_once DOL_DOCUMENT_ROOT .'/core/db/DoliDB.class.php';
 
 /**
- *	\class      DoliDBPgsql
- *	\brief      Class to drive a Postgresql database for Dolibarr
+ *	Class to drive a Postgresql database for Dolibarr
  */
-class DoliDBPgsql
+class DoliDBPgsql extends DoliDB
 {
     //! Database handler
     var $db;
@@ -41,7 +41,9 @@ class DoliDBPgsql
     //! Database label
 	static $label='PostgreSQL';      // Label of manager
 	//! Charset
-	var $forcecharset='UTF8';      // Can't be static as it may be forced with a dynamic value
+	var $forcecharset='UTF8';       // Can't be static as it may be forced with a dynamic value
+    //! Collate used to force collate when creating database
+    var $forcecollate='';			// Can't be static as it may be forced with a dynamic value
 	//! Version min database
 	static $versionmin=array(8,4,0);	// Version min database
 
@@ -55,15 +57,16 @@ class DoliDBPgsql
 	//! >=1 if a transaction is opened, 0 otherwise
 	var $transaction_opened;
 	var $lastquery;
-	var $lastqueryerror;		// Ajout d'une variable en cas d'erreur
+	// Saved last error
+	var $lastqueryerror;
+	var $lasterror;
+	var $lasterrno;
 
 	var $unescapeslashquot=0;              // By default we do not force the unescape of \'. This is used only to process sql with mysql escaped data.
 	var $standard_conforming_strings=1;    // Database has option standard_conforming_strings to on
 
 	var $ok;
 	var $error;
-	var $lasterror;
-
 
 
 	/**
@@ -176,6 +179,10 @@ class DoliDBPgsql
 		}
 		if ($line != "")
 		{
+			// group_concat support (PgSQL >= 9.1)
+			$line = preg_replace('/GROUP_CONCAT/i', 'STRING_AGG', $line);
+			$line = preg_replace('/ SEPARATOR/i', ',', $line);
+
 		    if ($type == 'auto')
 		    {
               if (preg_match('/ALTER TABLE/i',$line)) $type='dml';
@@ -183,6 +190,8 @@ class DoliDBPgsql
               else if (preg_match('/DROP TABLE/i',$line)) $type='dml';
 		    }
 
+    		$line=preg_replace('/ as signed\)/i',' as integer)',$line);
+
 		    if ($type == 'dml')
 		    {
                 $line=preg_replace('/\s/',' ',$line);   // Replace tabulation with space
@@ -202,7 +211,8 @@ class DoliDBPgsql
     			}
 
     			// tinyint type conversion
-    			$line=str_replace('tinyint','smallint',$line);
+    			$line=preg_replace('/tinyint\(?[0-9]*\)?/','smallint',$line);
+    			$line=preg_replace('/tinyint/i','smallint',$line);
 
     			// nuke unsigned
     			$line=preg_replace('/(int\w+|smallint)\s+unsigned/i','\\1',$line);
@@ -226,13 +236,13 @@ class DoliDBPgsql
     			$line=preg_replace('/^float/i','numeric',$line);
     			$line=preg_replace('/(\s*)float/i','\\1numeric',$line);
 
-    			//Check tms timestamp field case (in Mysql this field is defautled to now and 
+    			//Check tms timestamp field case (in Mysql this field is defautled to now and
     			// on update defaulted by now
     			$line=preg_replace('/(\s*)tms(\s*)timestamp/i','\\1tms timestamp without time zone DEFAULT now() NOT NULL',$line);
-    			
+
     			// nuke ON UPDATE CURRENT_TIMESTAMP
     			$line=preg_replace('/(\s*)on(\s*)update(\s*)CURRENT_TIMESTAMP/i','\\1',$line);
-    			
+
     			// unique index(field1,field2)
     			if (preg_match('/unique index\s*\((\w+\s*,\s*\w+)\)/i',$line))
     			{
@@ -243,17 +253,17 @@ class DoliDBPgsql
     			$line=preg_replace('/\sAFTER [a-z0-9_]+/i','',$line);
 
     			// We remove start of requests "ALTER TABLE tablexxx" if this is a DROP INDEX
-    			$line=preg_replace('/ALTER TABLE [a-z0-9_]+ DROP INDEX/i','DROP INDEX',$line);
+    			$line=preg_replace('/ALTER TABLE [a-z0-9_]+\s+DROP INDEX/i','DROP INDEX',$line);
 
                 // Translate order to rename fields
-                if (preg_match('/ALTER TABLE ([a-z0-9_]+) CHANGE(?: COLUMN)? ([a-z0-9_]+) ([a-z0-9_]+)(.*)$/i',$line,$reg))
+                if (preg_match('/ALTER TABLE ([a-z0-9_]+)\s+CHANGE(?: COLUMN)? ([a-z0-9_]+) ([a-z0-9_]+)(.*)$/i',$line,$reg))
                 {
                 	$line = "-- ".$line." replaced by --\n";
                     $line.= "ALTER TABLE ".$reg[1]." RENAME COLUMN ".$reg[2]." TO ".$reg[3];
                 }
 
                 // Translate order to modify field format
-                if (preg_match('/ALTER TABLE ([a-z0-9_]+) MODIFY(?: COLUMN)? ([a-z0-9_]+) (.*)$/i',$line,$reg))
+                if (preg_match('/ALTER TABLE ([a-z0-9_]+)\s+MODIFY(?: COLUMN)? ([a-z0-9_]+) (.*)$/i',$line,$reg))
                 {
                     $line = "-- ".$line." replaced by --\n";
                     $newreg3=$reg[3];
@@ -451,6 +461,16 @@ class DoliDBPgsql
 		return explode('.',$this->getVersion());
 	}
 
+	/**
+	 *	Return version of database client driver
+	 *
+	 *	@return	        string      Version string
+	 */
+	function getDriverInfo()
+	{
+		return '';
+	}
+
     /**
      *  Close database connexion
      *
@@ -582,17 +602,17 @@ class DoliDBPgsql
 		{
 			if (! $ret)
 			{
-			    if ($this->errno() != 'DB_ERROR_25P02')
+			    if ($this->errno() != 'DB_ERROR_25P02')	// Do not overwrite errors if this is a consecutive error
 			    {
     				$this->lastqueryerror = $query;
     				$this->lasterror = $this->error();
     				$this->lasterrno = $this->errno();
 			    }
-				dol_syslog(get_class($this)."::query SQL error usesavepoint = ".$usesavepoint." - ".$query." - ".pg_last_error($this->db)." = ".$this->errno(), LOG_WARNING);
+				dol_syslog(get_class($this)."::query SQL error usesavepoint = ".$usesavepoint." - ".$query." - ".pg_last_error($this->db)." => ".$this->errno(), LOG_WARNING);
 				//print "\n>> ".$query."<br>\n";
 				//print '>> '.$this->lasterrno.' - '.$this->lasterror.' - '.$this->lastqueryerror."<br>\n";
 
-				if ($usesavepoint && $this->transaction_opened)
+				if ($usesavepoint && $this->transaction_opened)	// Warning, after that errno will be erased
 				{
 					@pg_query($this->db, 'ROLLBACK TO SAVEPOINT mysavepoint');
 				}
@@ -690,16 +710,17 @@ class DoliDBPgsql
 
 
 	/**
-	 * Defini les limites de la requete
-	 *
-	 * @param	int		$limit      nombre maximum de lignes retournees
-	 * @param	int		$offset     numero de la ligne a partir de laquelle recuperer les lignes
-	 * @return	string      		chaine exprimant la syntax sql de la limite
+     *	Define limits and offset of request
+     *
+     *	@param	int		$limit      Maximum number of lines returned (-1=conf->liste_limit, 0=no limit)
+     *	@param	int		$offset     Numero of line from where starting fetch
+     *	@return	string      		String with SQL syntax to add a limit and offset
 	 */
 	function plimit($limit=0,$offset=0)
 	{
 		global $conf;
-		if (! $limit) $limit=$conf->liste_limit;
+        if (empty($limit)) return "";
+		if ($limit < 0) $limit=$conf->liste_limit;
 		if ($offset > 0) return " LIMIT ".$limit." OFFSET ".$offset." ";
 		else return " LIMIT $limit ";
 	}
@@ -857,7 +878,7 @@ class DoliDBPgsql
 			42701=> 'DB_ERROR_COLUMN_ALREADY_EXISTS',
 			'42710' => 'DB_ERROR_KEY_NAME_ALREADY_EXISTS',
 			'23505' => 'DB_ERROR_RECORD_ALREADY_EXISTS',
-			'42704' => 'DB_ERROR_NO_INDEX_TO_DROP',
+			'42704' => 'DB_ERROR_NO_INDEX_TO_DROP',		// May also be Type xxx does not exists
 			'42601' => 'DB_ERROR_SYNTAX',
 			'42P16' => 'DB_ERROR_PRIMARY_KEY_ALREADY_EXISTS',
 			1075 => 'DB_ERROR_CANT_DROP_PRIMARY_KEY',
@@ -1235,7 +1256,7 @@ class DoliDBPgsql
 			$sql.="(".$field_desc['value'].")";
 		}
 
-		// FIXME May not work with pgsql. May need to run a second request. If it works, just remove the FIXME tag
+		// TODO May not work with pgsql. May need to run a second request. If it works, just remove the comment
 		if ($field_desc['null'] == 'not null' || $field_desc['null'] == 'NOT NULL') $sql.=" NOT NULL";
 
 		dol_syslog($sql,LOG_DEBUG);
