@@ -77,7 +77,7 @@ class Holiday extends CommonObject
 
 
     /**
-     * updateSold
+     * updateSold. Update sold and check table of users for holidays is complete. If not complete.
      *
      * @return	int			Return 1
      */
@@ -886,7 +886,7 @@ class Holiday extends CommonObject
             $month = date('m',$now);
             $lastUpdate = $this->getConfCP('lastUpdate');
             $monthLastUpdate = $lastUpdate[4].$lastUpdate[5];
-			//print 'month: '.$month.' '.$lastUpdate.' '.$monthLastUpdate;
+			//print 'month: '.$month.' '.$lastUpdate.' '.$monthLastUpdate;exit;
 
             // Si la date du mois n'est pas la même que celle sauvegardée, on met à jour le timestamp
             if ($month != $monthLastUpdate)
@@ -983,25 +983,31 @@ class Holiday extends CommonObject
      */
     function createCPusers($single=false,$userid='')
     {
-        // Si c'est l'ensemble des utilisateurs à ajoutés
-        if(!$single)
+        // Si c'est l'ensemble des utilisateurs à ajouter
+        if (! $single)
         {
         	dol_syslog(get_class($this).'::createCPusers');
-            foreach($this->fetchUsers(false,true) as $users) {
+        	$arrayofusers = $this->fetchUsers(false,true);
+
+            foreach($arrayofusers as $users)
+            {
                 $sql = "INSERT INTO ".MAIN_DB_PREFIX."holiday_users";
                 $sql.= " (fk_user, nb_holiday)";
                 $sql.= " VALUES ('".$users['rowid']."','0')";
 
-                $this->db->query($sql);
+                $resql=$this->db->query($sql);
+                if (! $resql) dol_print_error($this->db);
             }
-        } else {
+        }
+        else
+		{
             $sql = "INSERT INTO ".MAIN_DB_PREFIX."holiday_users";
             $sql.= " (fk_user, nb_holiday)";
             $sql.= " VALUES ('".$userid."','0')";
 
-            $this->db->query($sql);
+            $resql=$this->db->query($sql);
+            if (! $resql) dol_print_error($this->db);
         }
-
     }
 
     /**
@@ -1048,7 +1054,7 @@ class Holiday extends CommonObject
      *    uniquement pour vérifier si il existe de nouveau utilisateur
      *
      *    @param      boolean	$liste	    si vrai retourne une liste, si faux retourne un array
-     *    @param      boolean   $type		si vrai retourne pour Dolibarr si faux retourne pour CP
+     *    @param      boolean   $type		si vrai retourne pour Dolibarr, si faux retourne pour CP
      *    @return     string      			retourne un tableau de tout les utilisateurs actifs
      */
     function fetchUsers($liste=true,$type=true)
@@ -1263,50 +1269,56 @@ class Holiday extends CommonObject
     function verifNbUsers($userDolibarrWithoutCP,$userCP) {
 
     	if (empty($userCP)) $userCP=0;
-    	dol_syslog(get_class($this).'::verifNbUsers userDolibarr='.$userDolibarr.' userCP='.$userCP);
+    	dol_syslog(get_class($this).'::verifNbUsers userDolibarr='.$userDolibarrWithoutCP.' userCP='.$userCP);
 
         // On vérifie les users Dolibarr sans CP
         if ($userDolibarrWithoutCP > 0)
         {
-            $this->updateConfCP('nbUser',$userDolibarr);
+        	$this->db->begin();
+
+            $this->updateConfCP('nbUser',$userDolibarrWithoutCP);
 
             $listUsersCP = $this->fetchUsers(true,false);
 
             // On séléctionne les utilisateurs qui ne sont pas déjà dans le module
             $sql = "SELECT u.rowid, u.lastname, u.firstname";
             $sql.= " FROM ".MAIN_DB_PREFIX."user as u";
-            $sql.= " WHERE u.rowid NOT IN(".$listUsersCP.")";
-
-            $result = $this->db->query($sql);
-
-            // Si pas d'erreur SQL
-            if($result) {
+            if ($listUsersCP != '') $sql.= " WHERE u.rowid NOT IN(".$listUsersCP.")";
 
+            $resql = $this->db->query($sql);
+            if ($resql)
+            {
                 $i = 0;
                 $num = $this->db->num_rows($resql);
 
-                while($i < $num) {
-
+                while($i < $num)
+                {
                     $obj = $this->db->fetch_object($resql);
+					$uid = $obj->rowid;
 
                     // On ajoute l'utilisateur
-                    $this->createCPusers(true,$obj->rowid);
+					//print "Add user rowid = ".$uid." into database holiday";
+
+                    $result = $this->createCPusers(true,$uid);
 
                     $i++;
                 }
 
-
+				$this->db->commit();
             } else {
                 // Erreur SQL
                 $this->error="Error ".$this->db->lasterror();
                 dol_syslog(get_class($this)."::verifNbUsers ".$this->error, LOG_ERR);
+                $this->db->rollback();
                 return -1;
             }
 
         } else {
-            // Si il y a moins d'utilisateur Dolibarr que dans le module CP
+        	$this->db->begin();
 
-            $this->updateConfCP('nbUser',$userDolibarr);
+        	// Si il y a moins d'utilisateur Dolibarr que dans le module CP
+
+            $this->updateConfCP('nbUser',$userDolibarrWithoutCP);
 
             $listUsersDolibarr = $this->fetchUsers(true,true);
 
@@ -1333,11 +1345,12 @@ class Holiday extends CommonObject
                     $i++;
                 }
 
-
+				$this->db->commit();
             } else {
                 // Erreur SQL
                 $this->error="Error ".$this->db->lasterror();
                 dol_syslog(get_class($this)."::verifNbUsers ".$this->error, LOG_ERR);
+                $this->db->rollback();
                 return -1;
             }
         }
@@ -1674,12 +1687,12 @@ class Holiday extends CommonObject
 
         // Filtrage de séléction
         if(!empty($filter)) {
-            $sql.= $filter;
+            $sql.= " ".$filter;
         }
 
         // Ordre d'affichage
         if(!empty($order)) {
-            $sql.= $order;
+            $sql.= " ".$order;
         }
 
         dol_syslog(get_class($this)."::fetchLog sql=".$sql, LOG_DEBUG);
